@@ -3,18 +3,19 @@ from allauth.account import app_settings as account_settings
 from allauth.account.adapter import get_adapter as get_account_adapter
 from allauth.account.authentication import get_authentication_records
 from allauth.account.internal import flows
-from allauth.account.models import EmailAddress
-from allauth.account.utils import user_display, user_username
+from allauth.headless.adapter import get_adapter
 from allauth.headless.constants import Flow
-from allauth.headless.internal import authkit, sessionkit
+from allauth.headless.internal import authkit
 from allauth.headless.internal.restkit.response import APIResponse
+from allauth.mfa import app_settings as mfa_settings
 
 
 class BaseAuthenticationResponse(APIResponse):
     def __init__(self, request, user=None, status=None):
         data = {}
         if user and user.is_authenticated:
-            data["user"] = user_data(user)
+            adapter = get_adapter()
+            data["user"] = adapter.serialize_user(user)
             data["methods"] = get_authentication_records(request)
             status = status or 200
         else:
@@ -24,7 +25,6 @@ class BaseAuthenticationResponse(APIResponse):
         meta = {
             "is_authenticated": user and user.is_authenticated,
         }
-        self._add_session_meta(request, meta)
         super().__init__(
             request,
             data=data,
@@ -32,33 +32,24 @@ class BaseAuthenticationResponse(APIResponse):
             status=status,
         )
 
-    def _add_session_meta(self, request, meta):
-        session_token = sessionkit.expose_session_token(request)
-        if session_token:
-            meta["session_token"] = session_token
-        access_token = authkit.expose_access_token(request)
-        if access_token:
-            meta["access_token"] = access_token
-
     def _get_flows(self, request, user):
         auth_status = authkit.AuthenticationStatus(request)
         ret = []
         if user and user.is_authenticated:
-            ret.extend(
-                [
-                    {"id": m["id"]}
-                    for m in get_account_adapter().get_reauthentication_methods(user)
-                ]
-            )
+            ret.extend(flows.reauthentication.get_reauthentication_flows(user))
         else:
-            ret.append({"id": Flow.LOGIN})
+            if not allauth_settings.SOCIALACCOUNT_ONLY:
+                ret.append({"id": Flow.LOGIN})
             if account_settings.LOGIN_BY_CODE_ENABLED:
                 code_flow = {"id": Flow.LOGIN_BY_CODE}
                 _, data = flows.login_by_code.get_pending_login(request, peek=True)
                 if data:
                     code_flow["is_pending"] = True
                 ret.append(code_flow)
-            if get_account_adapter().is_open_for_signup(request):
+            if (
+                get_account_adapter().is_open_for_signup(request)
+                and not allauth_settings.SOCIALACCOUNT_ONLY
+            ):
                 ret.append({"id": Flow.SIGNUP})
             if allauth_settings.SOCIALACCOUNT_ENABLED:
                 from allauth.headless.socialaccount.response import (
@@ -66,6 +57,9 @@ class BaseAuthenticationResponse(APIResponse):
                 )
 
                 ret.extend(provider_flows(request))
+            if allauth_settings.MFA_ENABLED:
+                if mfa_settings.PASSKEY_LOGIN_ENABLED:
+                    ret.append({"id": Flow.MFA_LOGIN_WEBAUTHN})
         stage_key = None
         stage = auth_status.get_pending_stage()
         if stage:
@@ -75,9 +69,23 @@ class BaseAuthenticationResponse(APIResponse):
             if isinstance(lsk, str):
                 stage_key = lsk
         if stage_key:
-            ret.append({"id": stage_key, "is_pending": True})
+            pending_flow = {"id": stage_key, "is_pending": True}
+            if stage and stage_key == Flow.MFA_AUTHENTICATE:
+                self._enrich_mfa_flow(stage, pending_flow)
+            ret.append(pending_flow)
         return ret
 
+    def _enrich_mfa_flow(self, stage, flow: dict) -> None:
+        from allauth.mfa.adapter import get_adapter as get_mfa_adapter
+        from allauth.mfa.models import Authenticator
+
+        adapter = get_mfa_adapter()
+        types = []
+        for typ in Authenticator.Type:
+            if adapter.is_mfa_enabled(stage.login.user, types=[typ]):
+                types.append(typ)
+        flow["types"] = types
+
 
 class AuthenticationResponse(BaseAuthenticationResponse):
     def __init__(self, request):
@@ -104,24 +112,6 @@ class ConflictResponse(APIResponse):
         super().__init__(request, status=409)
 
 
-def user_data(user):
-    """Basic user data, also exposed in partly authenticated scenario's
-    (e.g. password reset, email verification).
-    """
-    ret = {
-        "id": user.pk,
-        "display": user_display(user),
-        "has_usable_password": user.has_usable_password(),
-    }
-    email = EmailAddress.objects.get_primary_email(user)
-    if email:
-        ret["email"] = email
-    username = user_username(user)
-    if username:
-        ret["username"] = username
-    return ret
-
-
 def get_config_data(request):
     data = {
         "authentication_method": account_settings.AUTHENTICATION_METHOD,
