@@ -1,4 +1,4 @@
-class AppSettings(object):
+class AppSettings:
     def __init__(self, prefix):
         self.prefix = prefix
 
@@ -43,11 +43,36 @@ class AppSettings(object):
         """
         return self._setting("TOTP_ISSUER", "")
 
+    @property
+    def TOTP_INSECURE_BYPASS_CODE(self):
+        """
+        Don't use this on production. Useful for development & E2E tests only.
+        """
+        from django.conf import settings
+        from django.core.exceptions import ImproperlyConfigured
+
+        code = self._setting("TOTP_INSECURE_BYPASS_CODE", None)
+        if (not settings.DEBUG) and code:
+            raise ImproperlyConfigured(
+                "MFA_TOTP_INSECURE_BYPASS_CODE is for testing purposes only"
+            )
+        return code
+
     @property
     def SUPPORTED_TYPES(self):
         dflt = ["recovery_codes", "totp"]
         return self._setting("SUPPORTED_TYPES", dflt)
 
+    @property
+    def WEBAUTHN_ALLOW_INSECURE_ORIGIN(self):
+        return self._setting("WEBAUTHN_ALLOW_INSECURE_ORIGIN", False)
+
+    @property
+    def PASSKEY_LOGIN_ENABLED(self) -> bool:
+        return "webauthn" in self.SUPPORTED_TYPES and self._setting(
+            "PASSKEY_LOGIN_ENABLED", False
+        )
+
 
 _app_settings = AppSettings("MFA_")
 
