@@ -1,4 +1,7 @@
 from allauth.socialaccount.providers.base import ProviderAccount
+from allauth.socialaccount.providers.basecamp.views import (
+    BasecampOAuth2Adapter,
+)
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 
 
@@ -6,18 +9,18 @@ class BasecampAccount(ProviderAccount):
     def get_avatar_url(self):
         return None
 
-    def to_str(self):
-        dflt = super(BasecampAccount, self).to_str()
-        return self.account.extra_data.get("name", dflt)
+    def get_user_data(self):
+        return self.account.extra_data.get("identity", {})
 
 
 class BasecampProvider(OAuth2Provider):
     id = "basecamp"
     name = "Basecamp"
     account_class = BasecampAccount
+    oauth2_adapter_class = BasecampOAuth2Adapter
 
-    def get_auth_params(self, request, action):
-        data = super(BasecampProvider, self).get_auth_params(request, action)
+    def get_auth_params_from_request(self, request, action):
+        data = super().get_auth_params_from_request(request, action)
         data["type"] = "web_server"
         return data
 
