@@ -1,6 +1,8 @@
 from django.test import Client
 from django.urls import reverse
 
+import pytest
+
 from allauth.usersessions.models import UserSession
 
 
@@ -18,7 +20,7 @@ def test_overall_flow(user, user_password):
     assert sessions[0].user_agent == "Mozilla Firefox"
     assert sessions[1].user_agent == "Nyxt"
     for client in [firefox, nyxt]:
-        resp = firefox.get(reverse("usersessions_list"))
+        resp = client.get(reverse("usersessions_list"))
         assert resp.status_code == 200
     resp = firefox.post(reverse("usersessions_list"))
     assert resp.status_code == 302
@@ -30,3 +32,29 @@ def test_overall_flow(user, user_password):
     assert resp["location"] == reverse("account_login") + "?next=" + reverse(
         "usersessions_list"
     )
+
+
+@pytest.mark.parametrize("logout_on_passwd_change", [True, False])
+def test_change_password_updates_user_session(
+    settings, logout_on_passwd_change, client, user, user_password, password_factory
+):
+    settings.ACCOUNT_LOGOUT_ON_PASSWORD_CHANGE = logout_on_passwd_change
+    resp = client.post(
+        reverse("account_login"),
+        {"login": user.username, "password": user_password},
+    )
+    assert resp.status_code == 302
+    assert len(UserSession.objects.purge_and_list(user)) == 1
+
+    new_password = password_factory()
+    resp = client.post(
+        reverse("account_change_password"),
+        {
+            "oldpassword": user_password,
+            "password1": new_password,
+            "password2": new_password,
+        },
+    )
+    assert len(UserSession.objects.purge_and_list(user)) == (
+        0 if logout_on_passwd_change else 1
+    )
